##########################################################################
# File:         IfUtils.pm
#
# Description:  Perl module that implements the utility functions for 
#               IfGen
#
##########################################################################

package IfUtils;

# To install the XML::LibXML module under Debian, apt-get libxml-libxml-perl
# Useful help on using this is in 'man XML::LibXML::Node'

use strict;
use XML::LibXML;

##########################################################################
# Public methods
##########################################################################

# Given a string, return a multiline string as a C/C++ comment.
# Lines are limited to a maximum line length of $maxLength characters.
# Takes 4 params:
#     - prefix string to use at the start of each line (e.g. "    /* ")
#     - postfix string to use at the end of each line (e.g. " */")
#     - max line length
#     - the string to turn into a comment
sub makeComment
{
    my $prefix    = shift;
    my $postfix   = shift;
    my $maxLength = shift;
    my $text      = shift;
    my $comment   = "";
    my $lineLimit = $maxLength - length($postfix);

    if ($text)
    {
        # Strip any line feed chars from the string
        $text =~ s/\n/ /g;

        # Convert any tabs to spaces
        $text =~ s/\t/ /g;

        # Start line with indent spaces and comment chars
        my $nextLine = $prefix;

        foreach my $word (split / /, $text)
        {
            # Can the next word fit on the line?
            if (length($nextLine) + length($word) < $lineLimit)
            {
                # Don't forget to put the space back in between words!
                $nextLine .= $word." ";
            }
            else
            {
                while (length($nextLine) < $lineLimit) { $nextLine .= " "; }
                $comment .= $nextLine.$postfix."\n";
                # Stick it on the next line
                $nextLine = $prefix.$word." ";
            }
        }

        while (length($nextLine) < $lineLimit) { $nextLine .= " "; }
        $comment .= $nextLine.$postfix."\n";
    }

    return $comment;
}

sub commentBlock
{
    my $comment = shift;
    my $indent = shift;
    my $length = shift;

    if (!defined $length or $length == 0)
    {
        $length = 70;
    }

    if (!defined $indent)
    {
        $indent = 0;
    }

    my $prefix = "";
    for (my $count=0; $count < $indent; $count++)
    {
        $prefix .= " ";
    }

    print $prefix . "/";
    for (my $count=1; $count < ($length-1); $count++)
    {
        print "*";
    }
    print "\n";

    foreach my $line (split /\n/, $comment)
    {
        print IfUtils::makeComment($prefix." * ", "", $length, $line);
    }
    print $prefix . " ";
    for (my $count=1; $count < ($length-1); $count++)
    {
        print "*";
    }
    print "/\n";
}

sub preprocessText
{
    my $text = shift;

    # Strip any line feed chars from the string
    $text =~ s/\n/ /g;
    # Strip any leading whitespace from the string
    $text =~ s/^\s+//g;
    # Convert any tabs to spaces
    $text =~ s/\t/ /g;
    # Convert multiple whitespace to single space
    $text =~ s/\s+/ /g;

    return $text;
}

##########################################################################
# Must be last in class file - return true!
##########################################################################
1;

