/* packet-oyster3g-custom-apdiag_debug.c
 * Custom Routines for oyster3g apdiag_debug dissection
 *
 * $Id $
 *
 * Copyright (c) 2007 by ip.access Ltd <support@ipaccess.com>
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
 * Copyright 1999 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/* Include files */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdlib.h>
#include <ctype.h>
#include <epan/packet.h>
#include <epan/prefs.h>
#include <epan/strutil.h>

/* The following include defines the structures used for the static data
 * definitions which follow
 */

#include "packet-oyster3g.h"
#include "packet-oyster3g-apdiag_debug.h"


static dissector_handle_t ipaapptok_handle;
static dissector_handle_t ipastrtok_handle;

static int dissect_source_token_to_string(tvbuff_t *tvb, packet_info *pinfo, proto_tree *main_tree);
static int dissect_string_token_to_string(tvbuff_t *tvb, packet_info *pinfo, proto_tree *main_tree);

static custom_syntax_dissector_t token_msg_dissector[] =
{
	{SOURCETASK_SYNTAX,      &dissect_source_token_to_string},
	{TOKENNUMBER_SYNTAX,     &dissect_string_token_to_string},
	{0,NULL}
};

static int
dissect_source_token_to_string(tvbuff_t *tvb, packet_info *pinfo, proto_tree *main_tree)
{
    call_dissector(ipaapptok_handle, tvb, pinfo, main_tree);

    /* If we return 0 the normal dissection of the element is also displayed */
    return 0;
}

static int
dissect_string_token_to_string(tvbuff_t *tvb, packet_info *pinfo, proto_tree *main_tree)
{
    call_dissector(ipastrtok_handle, tvb, pinfo, main_tree);

    /* If we return 0 the normal dissection of the element is also displayed */
    return 0;
}

void oyster3g_register_custom_dissectors_apdiag_debug(const oyster3g_domain_t *domain _U_)
{
    return;
}

void oyster3g_register_custom_dissectors_handoff_apdiag_debug(const oyster3g_domain_t *domain)
{
    oyster3g_register_custom_dissectors(domain, token_msg_dissector);

    ipastrtok_handle = find_dissector("ipa_strtok");
    ipaapptok_handle = find_dissector("ipa_apptok");

    return;
}
