/* packet-oyster3g.h
 * Header file for ip.access oyster3G dissection
 * Copyright 2007, ip.access Ltd <support@ipaccess.com>
 *
 * $Id: plugins/oyster3g/packet-oyster3g.h 1.18 2008/08/05 11:01:44BST Norman Mackenzie (nm1) Exp  $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@unicom.net>
 * Copyright 1998 Gerald Combs
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef PACKET_OYSTER3G_H
#define PACKET_OYSTER3G_H

#include <epan/dissectors/packet-oyster3g-domain.h>

/* definitions for the framing */
#define OYSTER3G_HEADER_LEN              4
#define OYSTER3G_SOIP_VERSION            1

/* definitions of the streams used to link from the SoIP to domain dissectors */
#define OYSTER3G_URSLSOIP_STREAM                    0
#define OYSTER3G_BSMIS_SOIP_STREAM                  1
#define OYSTER3G_APDIAG_DEBUG_SOIP_STREAM           2
#define OYSTER3G_APDIAG_TRACE_SOIP_STREAM           3

#define OYSTER3G_SOIPCHANNEL_CONTROL_SOIP_STREAM  255

/* Definition of TCP Ports for domain dissectors */

/* definitions of the TCP ports on which the SoIP/oyster3g main protocol runs */
#define OYSTER3G_SOIP_TCP_PORT    3052
#define OYSTER3G_SOIP_SSL_PORT    3072

/* Function prototypes of specific domain custom dissector registrations */
void oyster3g_register_custom_dissectors_bsmis(const oyster3g_domain_t *domain);
void oyster3g_register_custom_dissectors_ursl(const oyster3g_domain_t *domain);
void oyster3g_register_custom_dissectors_apdiag_debug(const oyster3g_domain_t *domain);
void oyster3g_register_custom_dissectors_apdiag_trace(const oyster3g_domain_t *domain);

/* Function prototypes of specific domain custom dissector handoff registrations */
void oyster3g_register_custom_dissectors_handoff_bsmis(const oyster3g_domain_t *domain);
void oyster3g_register_custom_dissectors_handoff_ursl(const oyster3g_domain_t *domain);
void oyster3g_register_custom_dissectors_handoff_apdiag_debug(const oyster3g_domain_t *domain);
void oyster3g_register_custom_dissectors_handoff_apdiag_trace(const oyster3g_domain_t *domain);

/* define use of custom dissector registrations */
#define OYSTER3G_BSMIS_CUSTOM_DISSECTORS
#define OYSTER3G_URSLCUSTOM_DISSECTORS
#define OYSTER3G_APDIAG_DEBUG_CUSTOM_DISSECTORS
#define OYSTER3G_APDIAG_TRACE_CUSTOM_DISSECTORS

#endif /* PACKET_OYSTER3G_H */
